@@ -8,6 +8,7 @@
 ################## prediction #########################
 ## predict values using a RK model:
 predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30, debug.level = -1, predict.method = c("RK", "KED"), nfold = 5, verbose = FALSE, nsim = 0, mask.extra = TRUE, block, zmin = -Inf, zmax = Inf, subsample = length(object@sp), coarsening.factor = 1, vgmmodel = object@vgmModel, subset.observations = !is.na(object@sp@coords[,1]), betas = c(0,1), extend = .5, ...){
+  
   predict.method <- predict.method[1]
   if(nsim<0|!is.numeric(nsim)){
     stop("To invoke conditional simulations set 'nsim' argument to a positive integer number")
@@ -95,8 +96,9 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
   if(any(class(object@regModel)=="quantregForest")){
     if(requireNamespace("quantregForest", quietly = TRUE)){
       ## select complete observations only:
-      f <- which(stats::complete.cases(predictionLocations@data[,covs]))
-      rp <- list(predict(object@regModel, data.frame(predictionLocations)[f,covs], quantiles=.5)) 
+      fdf <- data.frame(predictionLocations)[,covs]
+      f <- which(stats::complete.cases(fdf))
+      rp <- list(predict(object@regModel, fdf[f,], what=.5)) 
       variable <- attr(object@regModel$y, "name")[1]
     } else {
       rp <- NULL
@@ -112,8 +114,30 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
       variable <- NA
     }
   }
+  if(any(class(object@regModel)=="ranger")){
+    if(requireNamespace("ranger", quietly = TRUE)){
+      ## select complete observations only:
+      covs <- object@regModel$forest$independent.variable.names
+      fdf <- data.frame(predictionLocations)[,covs]
+      f <- which(stats::complete.cases(fdf))
+      rp <- list(predict(object@regModel, fdf[f,])$predictions) 
+      variable <- names(object@sp@data)[1]
+    } else {
+      rp <- NULL
+      variable <- NA
+    }
+  }
+  if(any(class(object@regModel)=="train")){
+    if(requireNamespace("caret", quietly = TRUE)){
+      rp <- list(predict(object@regModel, fdf[f,])) 
+      variable <- names(object@sp@data)[1]
+    } else {
+      rp <- NULL
+      variable <- NA
+    }
+  }
   ## rename the target variable:   
-  if(any(class(object@regModel) %in% c("randomForest", "rpart", "gls"))){
+  if(any(class(object@regModel) %in% c("randomForest", "rpart", "gls", "caret", "ranger"))){
     names(rp)[1] = "fit"
   }
        
@@ -192,12 +216,16 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
   if(any(class(object@regModel) %in% c("glm", "lme", "gls"))){
     observed@data[,paste(variable, "modelFit", sep=".")] <- fitted(object@regModel)[subset.observations]
   }
-  if(any(class(object@regModel) %in% c("rpart", "randomForest"))){
+  if(any(class(object@regModel) %in% c("rpart", "randomForest", "ranger", "caret"))){
+    f0 <- which(stats::complete.cases(data.frame(observed)[,covs]))
     if(any(class(object@regModel)=="quantregForest")){
-      f0 <- which(stats::complete.cases(observed@data[,covs]))
-      observed@data[f0,paste(variable, "modelFit", sep=".")] <- predict(object@regModel, newdata=data.frame(observed)[f0,covs], quantiles=.5)  
+      observed@data[f0,paste(variable, "modelFit", sep=".")] <- predict(object@regModel, newdata=data.frame(observed)[f0,covs], what=.5)  
     } else {
-      observed@data[,paste(variable, "modelFit", sep=".")] <- predict(object@regModel, newdata=data.frame(observed),  na.action = na.pass)
+      if(any(class(object@regModel)=="ranger")){
+        observed@data[f0,paste(variable, "modelFit", sep=".")] <- predict(object@regModel, data=data.frame(observed)[f0,covs])$predictions
+      } else { 
+        observed@data[,paste(variable, "modelFit", sep=".")] <- predict(object@regModel, newdata=data.frame(observed),  na.action = na.pass)
+      }
     }
     rp[["residual.scale"]] <- sqrt(mean((observed@data[,paste(variable, "residual", sep=".")])^2, na.rm=TRUE))
     if(is.null(rp[["residual.scale"]])){ rp[["residual.scale"]] <- NA } 
@@ -298,7 +326,7 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
             ## TH: Prediction error for randomForest
             message("Prediction error for 'randomForest' model estimated using the 'quantreg' package.")
             if(requireNamespace("quantregForest", quietly = TRUE)){
-              var.rf <- predict(object@regModel, predictionLocations@data[f,covs], quantiles=c((1-.682)/2, 1-(1-.682)/2))
+              var.rf <- predict(object@regModel, predictionLocations@data[f,covs], what=c((1-.682)/2, 1-(1-.682)/2))
               ## TH: this formula assumes that the errors follow a normal distribution! [https://en.wikipedia.org/wiki/File:Standard_deviation_diagram.svg]
               predictionLocations@data[f,"fit.var"] <- ((var.rf[,1] - var.rf[,2])/2)^2
             }
